Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/generate-nvidia-engine](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/generate-nvidia-engine) for the documentation of this CM script.
